@@ -13,10 +13,10 @@ import simplejson
 import unicodedata
 from contextlib import suppress
 from datetime import datetime
-from eevee.ingestion.converters import RecordToMongoConverter
-from eevee.ingestion.feeders import IngestionFeeder
-from eevee.ingestion.ingesters import Ingester
-from eevee.mongo import get_mongo
+from splitgill.ingestion.converters import RecordToMongoConverter
+from splitgill.ingestion.feeders import IngestionFeeder
+from splitgill.ingestion.ingesters import Ingester
+from splitgill.mongo import get_mongo
 
 from . import exceptions
 from .deletion import ReplaceDeletionFeeder
@@ -31,18 +31,18 @@ log = logging.getLogger(__name__)
 
 
 def ingest_resource(version, config, resource, data, replace, api_key):
-    '''
+    """
     Ingest a new version of a resource's data.
 
     :param version: the new version
-    :param config: the eevee config object
+    :param config: the splitgill config object
     :param resource: the resource dict
     :param data: the data to ingest (can be None if not using the API)
     :param replace: boolean indicating whether to replace the existing data or not
     :param api_key: the API key if the resource's CKAN URL is to be used as the source and the
                     resource is private
     :return: True if the ingest was successful, False if not
-    '''
+    """
     # cache the resource id as we use it a few times
     resource_id = resource['id']
 
@@ -50,11 +50,14 @@ def ingest_resource(version, config, resource, data, replace, api_key):
     # create a stats entry so that preparation progress can be tracked
     prep_stats_id = stats.start_operation(resource_id, stats.PREP, version)
     try:
-        data_file_name, data_file_metadata = prepare_resource(resource, version, prep_stats_id,
-                                                              data, api_key)
+        data_file_name, data_file_metadata = prepare_resource(
+            resource, version, prep_stats_id, data, api_key
+        )
     except Exception as e:
         stats.mark_error(prep_stats_id, e)
-        log.info(f'Prep failed for resource {resource_id} due to {e.__class__.__name__}: {str(e)}')
+        log.info(
+            f'Prep failed for resource {resource_id} due to {e.__class__.__name__}: {str(e)}'
+        )
         if isinstance(e, exceptions.IngestionException):
             # these exceptions are expected (validation problems for example)
             return False
@@ -79,7 +82,9 @@ def ingest_resource(version, config, resource, data, replace, api_key):
             ingester.ingest()
 
             if replace:
-                replace_feeder = ReplaceDeletionFeeder(version, resource_id, tracker, feeder.source)
+                replace_feeder = ReplaceDeletionFeeder(
+                    version, resource_id, tracker, feeder.source
+                )
                 # note that we use the same converter to ensure the ingestion time is the same
                 replace_ingester = Ingester(version, replace_feeder, converter, config)
                 # TODO: should we merge the replace ingest stats with the main ingest stats?
@@ -87,8 +92,12 @@ def ingest_resource(version, config, resource, data, replace, api_key):
         # we really don't care about errors
         with suppress(Exception):
             # create a details row
-            create_details(resource_id, version, data_file_metadata['fields'],
-                           data_file_metadata['file_hash'])
+            create_details(
+                resource_id,
+                version,
+                data_file_metadata['fields'],
+                data_file_metadata['file_hash'],
+            )
 
         return True
     except Exception as e:
@@ -101,11 +110,14 @@ def ingest_resource(version, config, resource, data, replace, api_key):
             os.remove(data_file_name)
 
 
-def prepare_resource(resource, version, stats_id, data=None, api_key=None, update_every=1000):
-    '''
-    Downloads, validates and then produces an intermediate file containing the rows from the
-    resource to be ingested. If the data parameter is provided then it is used as the resource data,
-    if not then the resource url is used and the data is extracted from the resource url.
+def prepare_resource(
+    resource, version, stats_id, data=None, api_key=None, update_every=1000
+):
+    """
+    Downloads, validates and then produces an intermediate file containing the rows from
+    the resource to be ingested. If the data parameter is provided then it is used as
+    the resource data, if not then the resource url is used and the data is extracted
+    from the resource url.
 
     The intermediate file is a JSONL file (newline-delimited JSON using UTF-8 -
     http://jsonlines.org/) which is compressed using GZIP. The first line of the file contains
@@ -128,11 +140,14 @@ def prepare_resource(resource, version, stats_id, data=None, api_key=None, updat
                          the intermediate file format). Setting this too low will cause the database
                          to be written to a lot which could cause performance issues
     :return: the name of the intermediate file and the metadata dict
-    '''
+    """
     name = os.path.join(tempfile.gettempdir(), f'{resource["id"]}_{version}.jsonl.gz')
 
     try:
-        with get_fp_and_reader_for_resource_data(resource, data, api_key) as (fp, reader):
+        with get_fp_and_reader_for_resource_data(resource, data, api_key) as (
+            fp,
+            reader,
+        ):
             # first of all compute a hash of the file so that we can test to see if it's different
             # from the last file we ingested
             last_file_hash = get_last_file_hash(resource['id'])
@@ -182,16 +197,22 @@ def prepare_resource(resource, version, stats_id, data=None, api_key=None, updat
                     row_data = simplejson.dumps(row, ensure_ascii=False)
                     # check that the unicode produced doesn't contain any crap characters that we
                     # won't be able to read during ingestion
-                    if any(unicodedata.category(character)[0] == 'C' for character in row_data):
+                    if any(
+                        unicodedata.category(character)[0] == 'C'
+                        for character in row_data
+                    ):
                         raise exceptions.InvalidCharacterException(count, row)
 
                     writer.write(row_data + '\n')
 
                     if count % update_every == 0:
-                        stats.update_stats(stats_id, {
-                            ImportStats.in_progress: True,
-                            ImportStats.count: count,
-                        })
+                        stats.update_stats(
+                            stats_id,
+                            {
+                                ImportStats.in_progress: True,
+                                ImportStats.count: count,
+                            },
+                        )
 
             return name, metadata
     except Exception:
@@ -203,9 +224,10 @@ def prepare_resource(resource, version, stats_id, data=None, api_key=None, updat
 
 @contextlib.contextmanager
 def get_fp_and_reader_for_resource_data(resource, data=None, api_key=None):
-    '''
-    Context manager which given a resource, yields a file pointer to the downloaded resource source
-    and a ResourceReader instance for reading the data from the file pointer.
+    """
+    Context manager which given a resource, yields a file pointer to the downloaded
+    resource source and a ResourceReader instance for reading the data from the file
+    pointer.
 
     If the data parameter is passed (should be a list of dicts) then no file pointer is yielded
     (None is yielded instead). A ResourceReader instance is yielded as normal.
@@ -216,7 +238,7 @@ def get_fp_and_reader_for_resource_data(resource, data=None, api_key=None):
                     key to get it. This is needed when the URL is the CKAN resource download URL
                     of a private resource. Can be None to indicate no API key is required
     :return: yields a file pointer and a ResourceReader instance
-    '''
+    """
     handled = False
     if data is None:
         # there will be a url in the resource dict
@@ -227,21 +249,27 @@ def get_fp_and_reader_for_resource_data(resource, data=None, api_key=None):
             resource_format = resource_format.lower()
         # headers for the download request, note that we only incldue the auth in the request if
         # the url is for an uploaded file, this prevents leaking the credentials
-        headers = {'Authorization': api_key} if (resource.get('url_type', None) == 'upload'
-                                                 and api_key) else {}
+        headers = (
+            {'Authorization': api_key}
+            if (resource.get('url_type', None) == 'upload' and api_key)
+            else {}
+        )
 
         if resource_format != 'zip':
             reader = get_reader(resource_format)
             if reader is not None:
                 # if we got a reader, download the resource data to a temporary file
-                with download_to_temp_file(url, compress=reader.compressible,
-                                           headers=headers) as temp:
+                with download_to_temp_file(
+                    url, compress=reader.compressible, headers=headers
+                ) as temp:
                     yield temp, reader
                     handled = True
         else:
             # the resource data source is a zip so we need to download the zip, look in it to see if
             # we can find a file to use and then use it. Apologies for the massively nested withs.
-            with download_to_temp_file(url, compress=False, headers=headers) as temp_download:
+            with download_to_temp_file(
+                url, compress=False, headers=headers
+            ) as temp_download:
                 with zipfile.ZipFile(temp_download) as temp_zip:
                     # sort the list of files so that we maintain a consistency when reading zips
                     for name in sorted(temp_zip.namelist()):
@@ -249,7 +277,9 @@ def get_fp_and_reader_for_resource_data(resource, data=None, api_key=None):
                         reader = get_reader(os.path.splitext(name)[1][1:])
                         if reader is not None:
                             with temp_zip.open(name, 'r') as zipped_file:
-                                with tempfile.NamedTemporaryFile(mode='w+b', delete=True) as temp:
+                                with tempfile.NamedTemporaryFile(
+                                    mode='w+b', delete=True
+                                ) as temp:
                                     # extract the file data from the zip
                                     if reader.compressible:
                                         with gzip.open(temp.name, mode='wb') as g:
@@ -271,14 +301,16 @@ def get_fp_and_reader_for_resource_data(resource, data=None, api_key=None):
 
 
 class DatastoreFeeder(IngestionFeeder):
-    '''
-    Ingestion feeder class for the versioned datastore. This feeder handles reading rows from the
-    intermediate data file format produced by the prepare_resource function above.
-    '''
+    """
+    Ingestion feeder class for the versioned datastore.
+
+    This feeder handles reading rows from the intermediate data file format produced by
+    the prepare_resource function above.
+    """
 
     def __init__(self, config, resource_id, version, data_file_name):
         '''
-        :param config: the eevee config object
+        :param config: the splitgill config object
         :param resource_id: the resource id
         :param version: the version of the data we're ingesting
         :param data_file_name: the name of the intermediate data file to read the data from
@@ -290,14 +322,14 @@ class DatastoreFeeder(IngestionFeeder):
         self._header = None
 
     def iter_rows(self, skip_header_row):
-        '''
-        Returns a generator which can be used to iterate over the rows in the data file. This
-        generator yields dicts and therefore handles reading and deserialising the rows so that you
-        don't have to.
+        """
+        Returns a generator which can be used to iterate over the rows in the data file.
+        This generator yields dicts and therefore handles reading and deserialising the
+        rows so that you don't have to.
 
         :param skip_header_row: whether to skip the header row or yield it as if it was a normal row
         :return: a generator of dicts
-        '''
+        """
         with gzip.open(self.data_file_name, 'rb') as gzip_file:
             # the data file is always in utf-8 format
             reader = codecs.getreader('utf-8')(gzip_file)
@@ -308,12 +340,12 @@ class DatastoreFeeder(IngestionFeeder):
                 yield simplejson.loads(line)
 
     def get_existing_max_id(self):
-        '''
+        """
         Figure out what the current max id is in this resource's collection.
 
         :return: the highest id in the collection currently (it'll be an int), or 0 if there
                 aren't any documents in the collection
-        '''
+        """
         with get_mongo(self.config, collection=self.resource_id) as mongo:
             # sort by id descending to get the highest
             doc_with_max_id = mongo.find_one(sort=[('id', -1)])
@@ -325,12 +357,13 @@ class DatastoreFeeder(IngestionFeeder):
 
     @property
     def header(self):
-        '''
-        Property providing access to the header in the data file. This function caches the header
-        dict in self._header for repeated use and thus avoids reading the file every time.
+        """
+        Property providing access to the header in the data file. This function caches
+        the header dict in self._header for repeated use and thus avoids reading the
+        file every time.
 
         :return: the header dict
-        '''
+        """
         if self._header is None:
             # load the header by just iterating over the first row in the data file
             self._header = next(self.iter_rows(skip_header_row=False))
@@ -338,15 +371,15 @@ class DatastoreFeeder(IngestionFeeder):
 
     @property
     def source(self):
-        '''
+        """
         Returns the source of the ingestion. This comes from the data file.
 
         :return: the source name
-        '''
+        """
         return self.header['source']
 
     def records(self):
-        '''
+        """
         Returns a generator of DatastoreRecords using the rows in the data file.
 
         The id of each yielded record is determined using either the _id field in the row or by an
@@ -367,7 +400,7 @@ class DatastoreFeeder(IngestionFeeder):
         says "I'm row 3" and thus clashing ids!
 
         :return: a generator of DatastoreRecords
-        '''
+        """
         # calculate the highest id we know about
         highest_id = max(self.get_existing_max_id(), self.header.get('max_id', 0))
         # create a generator which starts at the next number after the highest id
